@@ -3,7 +3,7 @@ import typing as T
 import json
 from pydantic import BaseModel, Field
 from fastapi.encoders import jsonable_encoder
-from .execute import execute
+from .execute import execute, execute_async
 from .gql import GQLException
 from .dgraph_model import DGraphModel
 from .node import Node
@@ -90,7 +90,7 @@ class Resolver(
     def params_and_fields(self) -> str:
         return f"{self.query_params.to_str()}{self.gql_fields_str()}"
 
-    def _get(self, kwargs_d: dict) -> T.Optional[NodeType]:
+    def make_get_query_str(self, kwargs_d: dict) -> str:
         kwargs = {k: v for k, v in kwargs_d.items() if v is not None}
         if not kwargs:
             raise GQLException(
@@ -102,19 +102,33 @@ class Resolver(
                 for field_name, val in kwargs.items()
             ]
         )
-        query_name = f"get{self.model.GQL.typename}"
-        s = f"{{ {query_name}({inner_params}){self.gql_fields_str()} }}"
+        s = f"{{ {self.get_query_name()}({inner_params}){self.gql_fields_str()} }}"
         print(s)
-        obj = execute(query_str=s)["data"][query_name]
-        if obj:
-            return self.parse_obj_nested(obj)
-        return None
+        return s
+
+    @classmethod
+    def get_query_name(cls) -> str:
+        return f"get{cls.model.GQL.typename}"
+
+    @classmethod
+    def query_query_name(cls) -> str:
+        return f"query{cls.model.GQL.typename}"
+
+    def make_query_query_str(self) -> str:
+        s = f"{{ {self.query_query_name()}{self.params_and_fields()} }}"
+        print(s)
+        return s
+
+    async def query_async(self) -> T.List[NodeType]:
+        s = self.make_query_query_str()
+        lst: T.List[dict] = (await execute_async(query_str=s))["data"][
+            self.query_query_name()
+        ]
+        return [self.parse_obj_nested(d) for d in lst]
 
     def query(self) -> T.List[NodeType]:
-        query_name = f"query{self.model.GQL.typename}"
-        s = f"{{ {query_name}{self.params_and_fields()} }}"
-        print(s)
-        lst: T.List[dict] = execute(query_str=s)["data"][query_name]
+        s = self.make_query_query_str()
+        lst: T.List[dict] = execute(query_str=s)["data"][self.query_query_name()]
         return [self.parse_obj_nested(d) for d in lst]
 
     def parse_obj_nested(self, gql_d: dict) -> NodeType:
@@ -136,9 +150,26 @@ class Resolver(
             node.cache.add(key=field, resolver=resolver, val=value_to_save, gql_d=gql_d)
         return node
 
+    def _get(self, kwargs_d: dict) -> T.Optional[NodeType]:
+        s = self.make_get_query_str(kwargs_d=kwargs_d)
+        obj = execute(query_str=s)["data"][self.get_query_name()]
+        if obj:
+            return self.parse_obj_nested(obj)
+        return None
+
+    async def _get_async(self, kwargs_d: dict) -> T.Optional[NodeType]:
+        s = self.make_get_query_str(kwargs_d=kwargs_d)
+        obj = (await execute_async(query_str=s))["data"][self.get_query_name()]
+        if obj:
+            return self.parse_obj_nested(obj)
+        return None
+
     def get(self, get_params: GetParamsType) -> T.Optional[NodeType]:
         return self._get(kwargs_d=get_params.dict())
 
+    async def get_async(self, get_params: GetParamsType) -> T.Optional[NodeType]:
+        return await self._get_async(kwargs_d=get_params.dict())
+
     def gerror(self, get_params: GetParamsType) -> NodeType:
         node = self.get(get_params=get_params)
         if not node:
